summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoStyleStack.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoStyleStack.h')
-rw-r--r--lib/kofficecore/KoStyleStack.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/lib/kofficecore/KoStyleStack.h b/lib/kofficecore/KoStyleStack.h
index f3c5faf1..4e6cfa7e 100644
--- a/lib/kofficecore/KoStyleStack.h
+++ b/lib/kofficecore/KoStyleStack.h
@@ -22,9 +22,9 @@
#define KOSTYLESTACK_H
-#include <qvaluelist.h>
-#include <qdom.h>
-#include <qvaluestack.h>
+#include <tqvaluelist.h>
+#include <tqdom.h>
+#include <tqvaluestack.h>
#include <kdemacros.h>
@@ -36,7 +36,7 @@
* There can be several styles that are valid for one object. For example
* a textobject on a page has styles 'pr3' and 'P7' and a paragraph in
* that textobject has styles 'P1' and 'T3'. And some styles even have
- * parent-styles...
+ * tqparent-styles...
*
* If you want to know if there is, for example, the attribute 'fo:font-family'
* for this paragraph, you have to look into style 'T3', 'P1', 'P7' and 'pr3'.
@@ -54,7 +54,7 @@
*
* In general though, you wouldn't use push/pop directly, but KoOasisLoadingContext::fillStyleStack
* or KoOasisLoadingContext::addStyles to automatically push a style and all its
- * parent styles onto the stack.
+ * tqparent styles onto the stack.
*/
class KOFFICECORE_EXPORT KoStyleStack
{
@@ -93,25 +93,25 @@ public:
/**
* Pushes the new style onto the stack.
*/
- void push( const QDomElement& style );
+ void push( const TQDomElement& style );
/**
* Check if any of the styles on the stack has an attribute called 'name'-'detail'
* where detail is e.g. left, right, top or bottom.
- * This allows to also find 'name' alone (e.g. padding implies padding-left, padding-right etc.)
+ * This allows to also tqfind 'name' alone (e.g. padding implies padding-left, padding-right etc.)
*/
- bool hasAttribute( const QString& name, const QString& detail = QString::null ) const KDE_DEPRECATED;
+ bool hasAttribute( const TQString& name, const TQString& detail = TQString() ) const KDE_DEPRECATED;
/**
* Search for the attribute called 'name', starting on top of the stack,
* and return it.
*/
- QString attribute( const QString& name, const QString& detail = QString::null ) const KDE_DEPRECATED;
+ TQString attribute( const TQString& name, const TQString& detail = TQString() ) const KDE_DEPRECATED;
/**
* Check if any of the styles on the stack has an attribute called 'name'-'detail'
* where detail is e.g. left, right, top or bottom.
- * This allows to also find 'name' alone (e.g. padding implies padding-left, padding-right etc.)
+ * This allows to also tqfind 'name' alone (e.g. padding implies padding-left, padding-right etc.)
*/
bool hasAttributeNS( const char* nsURI, const char* localName, const char* detail = 0 ) const;
@@ -119,18 +119,18 @@ public:
* Search for the attribute called 'name', starting on top of the stack,
* and return it.
*/
- QString attributeNS( const char* nsURI, const char* localName, const char* detail = 0 ) const;
+ TQString attributeNS( const char* nsURI, const char* localName, const char* detail = 0 ) const;
/**
* Check if any of the styles on the stack has a child node called 'name'.
*/
- bool hasChildNode( const QString & name ) const KDE_DEPRECATED;
+ bool hasChildNode( const TQString & name ) const KDE_DEPRECATED;
/**
* Search for a child node called 'name', starting on top of the stack,
* and return it.
*/
- QDomElement childNode( const QString & name ) const KDE_DEPRECATED;
+ TQDomElement childNode( const TQString & name ) const KDE_DEPRECATED;
/**
* Check if any of the styles on the stack has a child element called 'localName' in the namespace 'nsURI'.
@@ -142,7 +142,7 @@ public:
* in the namespace 'nsURI' starting on top of the stack,
* and return it.
*/
- QDomElement childNodeNS( const char* nsURI, const char* localName ) const;
+ TQDomElement childNodeNS( const char* nsURI, const char* localName ) const;
/**
* Special case for the current font size, due to special handling of fo:font-size="115%".
@@ -155,13 +155,13 @@ public:
* This is used to know e.g. which user-style is associated with the current paragraph.
* There could be none though.
*/
- QString userStyleName( const QString& family ) const;
+ TQString userStyleName( const TQString& family ) const;
/**
* Return the display name of the style specified by the user,
* i.e. not an auto style
*/
- QString userStyleDisplayName( const QString& family ) const;
+ TQString userStyleDisplayName( const TQString& family ) const;
/**
* Set the type of properties that will be looked for.
@@ -173,19 +173,19 @@ public:
void setTypeProperties( const char* typeProperties );
private:
- bool isUserStyle( const QDomElement& e, const QString& family ) const;
+ bool isUserStyle( const TQDomElement& e, const TQString& family ) const;
private:
/// For save/restore: stack of "marks". Each mark is an index in m_stack.
- QValueStack<int> m_marks;
+ TQValueStack<int> m_marks;
/**
* We use QValueList instead of QValueStack because we need access to all styles
* not only the top one.
*/
- QValueList<QDomElement> m_stack;
+ TQValueList<TQDomElement> m_stack;
- QCString m_propertiesTagName;
+ TQCString m_propertiesTagName;
const char* m_styleNSURI;
const char* m_foNSURI;
@@ -173,19 +173,19 @@ public:
/**
- * We use QValueList instead of QValueStack because we need access to all styles
+ * We use TQValueList instead of TQValueStack because we need access to all styles
* not only the top one.
*/